#define EXT_BUFSIZE     16
extern uint8_t ext_buf[];

#define DEV_SYS		0
#define DEV_ADC		1
#define DEV_OSC		2
#define DEV_FCNT	3
#define DEV_ECHO	9
#define DEV_I2C		10

/* i2c functions */
extern void init_i2c();
extern int8_t i2c_send(uint8_t dev, uint8_t size);
extern int8_t i2c_recv(uint8_t dev, uint8_t size);

/* ADC functions */

#define ADC_CHAN_AIN1		0x0 // ADC0
#define ADC_CHAN_AIN2		0x1 // ADC1
#define ADC_CHAN_AIN3		0x2 // ADC4
#define ADC_CHAN_AIN4		0x3 // ADC5
#define ADC_CHAN_AIN5		0x4 // ADC12
#define ADC_CHAN_AIN6		0x5 // ADC13
#define ADC_CHAN_VCC		0x6 // 
#define ADC_CHAN_TEMP		0x7 // internal #4 (TEMP)

#define ADC_CHAN_AIN31		0x8 
#define ADC_CHAN_AIN32		0x9
#define ADC_CHAN_AIN41		0xa
#define ADC_CHAN_AIN42		0xb
#define ADC_CHAN_AIN21		0xc

#define ADC_CHAN_DELTA		0x08
#define ADC_CHAN_MASK		0x0f

/* flags for DELTA mode */
#define ADC_RANGE_AUTO		0x00 // Auto Range
#define ADC_RANGE_V512		0x10 // Reference VCC
#define ADC_RANGE_V256		0x20 // Reference 2.56V
#define ADC_RANGE_V0256		0x30 // Reference 2.56V + Gain x10
#define ADC_RANGE_V0064		0x60 // Reference 2.56V + Gain x40
#define ADC_RANGE_V00128	0x70 // Reference 2.56V + Gain x200
#define ADC_RANGE_MASK		0x70
#define ADC_BIPOLAR		0x80 // use BIN : not supported

/* result format 
 *
 *  uint16_t: unit 0.078125 mV (10/128 mV)
 * x1 @ 2.56v referance
 *   +-+---------+---+
 *   |1| 10      | 5 |
 *   +-+---------+---+
 *
 */

extern void init_adc();
extern int8_t adc_send(uint8_t size);
extern int8_t adc_recv(uint8_t size);

/* fcnt functions */

extern int8_t fcnt_send(uint8_t size);
extern int8_t fcnt_recv(uint8_t size);

#define FCNT_START	0x01

/* osc functions */

extern void init_osc();
extern void term_osc();
extern int8_t osc_send(uint8_t size);
extern int8_t osc_recv(uint8_t size);

#define OSC_INIT	0x00
#define OSC_START	0x01
#define OSC_STOP	0x02
#define OSC_SET	0x03

/* SERJTAG speeds */
#define SERJTAG_SPEED_0_5    15  /* 500 Hz */
#define SERJTAG_SPEED_1      14  /*   1 kHz */
#define SERJTAG_SPEED_2      13  /*   2 kHz */
#define SERJTAG_SPEED_4      12  /*   4 kHz */
#define SERJTAG_SPEED_8      11  /*   8 kHz */
#define SERJTAG_SPEED_16     10  /*  16 kHz */
#define SERJTAG_SPEED_32     9   /*  32 kHz */
#define SERJTAG_SPEED_62_5   8   /* 62.5 kHz */
#define SERJTAG_SPEED_125    7   /* 125 kHz  */
#define SERJTAG_SPEED_250    6   /* 250 kHz  */
#define SERJTAG_SPEED_500    5   /* 500 kHz  */
#define SERJTAG_SPEED_1000   4   /* 1.0MHz  */
#define SERJTAG_SPEED_2000   3   /* 2.0MHz  */
#define SERJTAG_SPEED_4000   2   /* 4.0MHz  */
#define SERJTAG_SPEED_8000   1   /* 8.0MHz  */
#define SERJTAG_SPEED_AUTO   0
