#ifndef __aspconfig_h_included__
#define __aspconfig_h_included__

static inline void connect_led_on() {
    /* RX LED on */
    PORTD &= ~(1<< PD4);
    DDRD  |= (1<< PD4);
}

static inline void connect_led_off() {
    /* RX LED off (HI-Z) */
    PORTD &= ~(1<< PD4);
    DDRD  &= ~(1<< PD4);
}

static inline void busy_led_on() {
    /* internal LED on */
    PORTB &= ~(1<< PB4);
    DDRB  |= (1<< PB4);
    /* TX LED off(HI-Z): reversed */
    PORTD &= ~(1<< PD5);
    DDRD  &= ~(1<< PD5);
}

static inline void busy_led_off() {
    /* internal LED off */
    PORTB |= (1<< PB4);
    DDRB  |= (1<< PB4);
    /* TX LED on : reversed */
    PORTD &= ~(1<< PD5);
    DDRD  |= (1<< PD5);
}

static inline void clkout_start() {
	// 2M Hz timer = 1M Hz clockout
	DDRC |= (1<< PC5);
	OCR1A =  (F_CPU/1000/2000 - 1) & 0xffff;
	TCCR1C = 0;
	TCCR1A = (2<<COM1B0) | (0<<WGM10); // OC1B toggle
	TCCR1B = (1<<WGM12)|(1<<CS10);  // CTC  1/1
}

static inline void clkout_stop() {
	DDRC &= ~(1<< PC5);
	TCCR1B = 0;
	TCCR1A = 0;
}

#define ENABLE_ISP1
#define ISP_OUT   PORTB
#define ISP_IN    PINB
#define ISP_DDR   DDRB
#define ISP_RST   PB0	/* SS */
#define ISP_MOSI  PB2	/* MOSI = ISP MOSI */
#define ISP_MISO  PB3	/* MISO = ISP MISO */
#define ISP_SCK   PB1	/* SCLK */

//#define ENABLE_ISP2
#define ISP2_OUT   PORTD
#define ISP2_IN    PIND
#define ISP2_DDR   DDRD
#define ISP2_RST   PD1
#define ISP2_MOSI  PD3	/* MOSI = TX */
#define ISP2_MISO  PD2	/* MISO = RX */
#define ISP2_SCK   PD5	/* SCLK = XCK */
#define ISP2_DIR   PD4	/* for buffer control - L: TX , H or Hi-Z: RX */

#define ENABLE_PDI
#define ENABLE_TPI
//#define ENABLE_HARD_PDITPI
#define ENABLE_SOFT_PDITPI
//#define ENABLE_SOFT_XXX

#define PDITPI_OUT   PORTB
#define PDITPI_IN    PINB
#define PDITPI_DDR   DDRB
#define PDITPI_RST   PB0 // TPI_RESET
#define PDITPI_MOSI  PB3 // PDI_DATA , TPIDATA
//#define PDITPI_MISO  PB3
#define PDITPI_SCK   PB0 // PDI_CLK , TPICLK
#define PDITPI_DIR   PB2

static inline void pditpi_dir_init() {
	PDITPI_OUT |= (1<< PDITPI_DIR);
	PDITPI_DDR |= (1<< PDITPI_DIR);
}

static inline void pditpi_dir_tx() {
	PDITPI_OUT &= ~(1<< PDITPI_DIR);
}

static inline void pditpi_dir_rx() {
	PDITPI_OUT |= (1<< PDITPI_DIR);
}

static inline int8_t pditpi_dir_is_tx() {
	return !(PDITPI_OUT & (1<< PDITPI_DIR));
}

static inline void tpi_reset(uchar is_assert) {
#ifdef PDITPI_RST
	if (is_assert) {
		PDITPI_DDR |=(1<< PDITPI_RST); // L 
	} else {
		PDITPI_DDR &= ~(1<< PDITPI_RST); // HI-Z
	}
#endif
}

#ifdef SERIAL_DEBUG
extern void debug_putc(uint8_t ch);
extern void debug_puts(char *buf);
extern void debug_put_hex(uint8_t v);
#endif
#endif /* __aspconfig_h_included__ */
